@@ -463,7 +463,7 @@ srconf_init (SRConfCB srconfcb,
 	
 	    if (error != NULL)
 	    {
-		sru_warning(_("Failed to add notify.:%s"), error->message);
+		sru_warning(_("Failed to add notify: %s"), error->message);
 		sru_warning(_(error->message));
 		g_error_free (error);
 		error = NULL;
